@@ -32,7 +32,7 @@
 
 static const QString serverContent1 = QStringLiteral(
         // The format of these lines are first a type, either 'C' or 'I' for Item and collection.
-        // The dashes show the depth in the heirarchy
+        // The dashes show the depth in the hierarchy
         // Collections have a list of mimetypes they can contain, followed by an optional
         // displayName which is put into the EntityDisplayAttribute, followed by an optional order
         // which is the order in which the collections are returned from the job to the ETM.
@@ -97,52 +97,21 @@ private Q_SLOTS:
     void testRemoveCollectionOnChanged();
 
 private:
-    ExpectedSignal getExpectedSignal(SignalType type, int start, int end, const QVariantList newData)
-    {
-        return getExpectedSignal(type, start, end, QVariant(), newData);
-    }
-
-    ExpectedSignal getExpectedSignal(SignalType type, int start, int end, const QVariant &parentData = QVariant(), const QVariantList newData = QVariantList())
-    {
-        ExpectedSignal expectedSignal;
-        expectedSignal.signalType = type;
-        expectedSignal.startRow = start;
-        expectedSignal.endRow = end;
-        expectedSignal.parentData = parentData;
-        expectedSignal.newData = newData;
-        return expectedSignal;
-    }
-
-    ExpectedSignal getExpectedSignal(SignalType type, int start, int end, const QVariant &sourceParentData, int destRow, const QVariant &destParentData, const QVariantList newData)
-    {
-        ExpectedSignal expectedSignal;
-        expectedSignal.signalType = type;
-        expectedSignal.startRow = start;
-        expectedSignal.endRow = end;
-        expectedSignal.sourceParentData = sourceParentData;
-        expectedSignal.destRow = destRow;
-        expectedSignal.parentData = destParentData;
-        expectedSignal.newData = newData;
-        return expectedSignal;
-    }
-
     QPair<FakeServerData *, Akonadi::EntityTreeModel *> populateModel(const QString &serverContent, const QString &mimeType = QString())
     {
-        FakeMonitor *fakeMonitor = new FakeMonitor(this);
+        const auto fakeMonitor = new FakeMonitor(this);
 
         fakeMonitor->setSession(m_fakeSession);
         fakeMonitor->setCollectionMonitored(Collection::root());
         if (!mimeType.isEmpty()) {
             fakeMonitor->setMimeTypeMonitored(mimeType);
         }
-        EntityTreeModel *model = new EntityTreeModel(fakeMonitor, this);
+        const auto model = new EntityTreeModel(fakeMonitor, this);
 
-        m_modelSpy = new ModelSpy(this);
-        m_modelSpy->setModel(model);
+        m_modelSpy = new ModelSpy{model, this};
 
-        FakeServerData *serverData = new FakeServerData(model, m_fakeSession, fakeMonitor);
-        QList<FakeAkonadiServerCommand *> initialFetchResponse =  FakeJobResponse::interpret(serverData, serverContent);
-        serverData->setCommands(initialFetchResponse);
+        const auto serverData = new FakeServerData(model, m_fakeSession, fakeMonitor);
+        serverData->setCommands(FakeJobResponse::interpret(serverData, serverContent));
 
         // Give the model a chance to populate
         QTest::qWait(100);
@@ -156,6 +125,16 @@ private:
 
 };
 
+QModelIndex firstMatchedIndex(const QAbstractItemModel &model, const QString pattern)
+{
+    if (pattern.isEmpty()) {
+        return {};
+    }
+    const auto list = model.match(model.index(0, 0), Qt::DisplayRole, pattern, 1, Qt::MatchRecursive);
+    Q_ASSERT(!list.isEmpty());
+    return list.first();
+}
+
 void EntityTreeModelTest::initTestCase()
 {
     m_sessionName = "EntityTreeModelTest fake session";
@@ -167,60 +146,56 @@ void EntityTreeModelTest::initTestCase()
 
 void EntityTreeModelTest::testInitialFetch()
 {
-    FakeMonitor *fakeMonitor = new FakeMonitor(this);
+    const auto fakeMonitor = new FakeMonitor(this);
 
     fakeMonitor->setSession(m_fakeSession);
     fakeMonitor->setCollectionMonitored(Collection::root());
-    EntityTreeModel *model = new EntityTreeModel(fakeMonitor, this);
+    const auto model = new EntityTreeModel(fakeMonitor, this);
 
-    FakeServerData *serverData = new FakeServerData(model, m_fakeSession, fakeMonitor);
-    QList<FakeAkonadiServerCommand *> initialFetchResponse =  FakeJobResponse::interpret(serverData, serverContent1);
-    serverData->setCommands(initialFetchResponse);
+    const auto serverData = new FakeServerData(model, m_fakeSession, fakeMonitor);
+    serverData->setCommands(FakeJobResponse::interpret(serverData, serverContent1));
 
-    m_modelSpy = new ModelSpy(this);
-    m_modelSpy->setModel(model);
+    m_modelSpy = new ModelSpy(model, this);
     m_modelSpy->startSpying();
 
-    QList<ExpectedSignal> expectedSignals;
-
-    // First the model gets a signal about the first collection to be returned, which is not a top-level collection.
-    // It uses the parentCollection heirarchy to put placeholder collections in the model until the root is reached.
-    // Then it inserts only one row and emits the correct signals. After that, when the other collections
-    // arrive, dataChanged is emitted for them.
-
-    expectedSignals << getExpectedSignal(RowsAboutToBeInserted, 0, 0);
-    expectedSignals << getExpectedSignal(RowsInserted, 0, 0);
-    expectedSignals << getExpectedSignal(DataChanged, 0, 0, QVariantList() << QStringLiteral("Col 4"));
-    expectedSignals << getExpectedSignal(DataChanged, 0, 0, QVariantList() << QStringLiteral("Col 3"));
-    // New collections are prepended
-    expectedSignals << getExpectedSignal(RowsAboutToBeInserted, 0, 0, QStringLiteral("Collection 1"));
-    expectedSignals << getExpectedSignal(RowsInserted, 0, 0, QStringLiteral("Collection 1"), QVariantList() << QStringLiteral("Col 2"));
-    expectedSignals << getExpectedSignal(RowsAboutToBeInserted, 0, 0, QStringLiteral("Collection 1"));
-    expectedSignals << getExpectedSignal(RowsInserted, 0, 0, QStringLiteral("Collection 1"), QVariantList() << QStringLiteral("Col 6"));
-    expectedSignals << getExpectedSignal(RowsAboutToBeInserted, 0, 0, QStringLiteral("Collection 1"));
-    expectedSignals << getExpectedSignal(RowsInserted, 0, 0, QStringLiteral("Collection 1"), QVariantList() << QStringLiteral("Col 7"));
-    expectedSignals << getExpectedSignal(DataChanged, 0, 0, QVariantList() << QStringLiteral("Col 1"));
-    // The items in the collections are appended.
-    expectedSignals << getExpectedSignal(RowsAboutToBeInserted, 0, 3, QStringLiteral("Col 2"));
-    expectedSignals << getExpectedSignal(RowsInserted, 0, 3, QStringLiteral("Col 2"));
-    expectedSignals << getExpectedSignal(RowsAboutToBeInserted, 0, 1, QStringLiteral("Col 5"));
-    expectedSignals << getExpectedSignal(RowsInserted, 0, 1, QStringLiteral("Col 5"));
-    expectedSignals << getExpectedSignal(RowsAboutToBeInserted, 1, 1, QStringLiteral("Col 4"));
-    expectedSignals << getExpectedSignal(RowsInserted, 1, 1, QStringLiteral("Col 4"));
-    expectedSignals << getExpectedSignal(RowsAboutToBeInserted, 1, 2, QStringLiteral("Col 3"));
-    expectedSignals << getExpectedSignal(RowsInserted, 1, 2, QStringLiteral("Col 3"));
-    expectedSignals << getExpectedSignal(RowsAboutToBeInserted, 0, 1, QStringLiteral("Col 6"));
-    expectedSignals << getExpectedSignal(RowsInserted, 0, 1, QStringLiteral("Col 6"));
-    expectedSignals << getExpectedSignal(RowsAboutToBeInserted, 0, 3, QStringLiteral("Col 7"));
-    expectedSignals << getExpectedSignal(RowsInserted, 0, 3, QStringLiteral("Col 7"));
-    expectedSignals << getExpectedSignal(DataChanged, 0, 0, QVariantList() << QStringLiteral("Col 1"));
-    expectedSignals << getExpectedSignal(DataChanged, 3, 3, QVariantList() << QStringLiteral("Col 3"));
-    expectedSignals << getExpectedSignal(DataChanged, 0, 0, QVariantList() << QStringLiteral("Col 5"));
-    expectedSignals << getExpectedSignal(DataChanged, 0, 0, QVariantList() << QStringLiteral("Col 4"));
-    expectedSignals << getExpectedSignal(DataChanged, 2, 2, QVariantList() << QStringLiteral("Col 2"));
-    expectedSignals << getExpectedSignal(DataChanged, 1, 1, QVariantList() << QStringLiteral("Col 7"));
-    expectedSignals << getExpectedSignal(DataChanged, 0, 0, QVariantList() << QStringLiteral("Col 6"));
-
+    const QList<ExpectedSignal> expectedSignals {
+        // First the model gets a signal about the first collection to be returned, which is not a top-level collection.
+        // It uses the parentCollection hierarchy to put placeholder collections in the model until the root is reached.
+        // Then it inserts only one row and emits the correct signals. After that, when the other collections
+        // arrive, dataChanged is emitted for them.
+        {RowsAboutToBeInserted, 0, 0},
+        {RowsInserted, 0, 0},
+        {DataChanged, 0, 0, QVariantList{QStringLiteral("Col 4")}},
+        {DataChanged, 0, 0, QVariantList{QStringLiteral("Col 3")}},
+        // New collections are prepended
+        {RowsAboutToBeInserted, 0, 0, QStringLiteral("Collection 1")},
+        {RowsInserted, 0, 0, QStringLiteral("Collection 1"), QVariantList{QStringLiteral("Col 2")}},
+        {RowsAboutToBeInserted, 0, 0, QStringLiteral("Collection 1")},
+        {RowsInserted, 0, 0, QStringLiteral("Collection 1"), QVariantList{QStringLiteral("Col 6")}},
+        {RowsAboutToBeInserted, 0, 0, QStringLiteral("Collection 1")},
+        {RowsInserted, 0, 0, QStringLiteral("Collection 1"), QVariantList{QStringLiteral("Col 7")}},
+        {DataChanged, 0, 0, QVariantList{QStringLiteral("Col 1")}},
+        // The items in the collections are appended.
+        {RowsAboutToBeInserted, 0, 3, QStringLiteral("Col 2")},
+        {RowsInserted, 0, 3, QStringLiteral("Col 2")},
+        {RowsAboutToBeInserted, 0, 1, QStringLiteral("Col 5")},
+        {RowsInserted, 0, 1, QStringLiteral("Col 5")},
+        {RowsAboutToBeInserted, 1, 1, QStringLiteral("Col 4")},
+        {RowsInserted, 1, 1, QStringLiteral("Col 4")},
+        {RowsAboutToBeInserted, 1, 2, QStringLiteral("Col 3")},
+        {RowsInserted, 1, 2, QStringLiteral("Col 3")},
+        {RowsAboutToBeInserted, 0, 1, QStringLiteral("Col 6")},
+        {RowsInserted, 0, 1, QStringLiteral("Col 6")},
+        {RowsAboutToBeInserted, 0, 3, QStringLiteral("Col 7")},
+        {RowsInserted, 0, 3, QStringLiteral("Col 7")},
+        {DataChanged, 0, 0, QVariantList{QStringLiteral("Col 1")}},
+        {DataChanged, 3, 3, QVariantList{QStringLiteral("Col 3")}},
+        {DataChanged, 0, 0, QVariantList{QStringLiteral("Col 5")}},
+        {DataChanged, 0, 0, QVariantList{QStringLiteral("Col 4")}},
+        {DataChanged, 2, 2, QVariantList{QStringLiteral("Col 2")}},
+        {DataChanged, 1, 1, QVariantList{QStringLiteral("Col 7")}},
+        {DataChanged, 0, 0, QVariantList{QStringLiteral("Col 6")}}
+    };
     m_modelSpy->setExpectedSignals(expectedSignals);
 
     // Give the model a chance to run the event loop to process the signals.
@@ -260,26 +235,24 @@ void EntityTreeModelTest::testCollectionMove()
     QFETCH(QString, movedCollection);
     QFETCH(QString, targetCollection);
 
-    QPair<FakeServerData *, Akonadi::EntityTreeModel *> testDrivers = populateModel(serverContent);
-    FakeServerData *serverData = testDrivers.first;
-    Akonadi::EntityTreeModel *model = testDrivers.second;
+    const auto testDrivers = populateModel(serverContent);
+    const auto serverData = testDrivers.first;
+    const auto model = testDrivers.second;
 
-    QModelIndexList list = model->match(model->index(0, 0), Qt::DisplayRole, movedCollection, 1, Qt::MatchRecursive);
-    Q_ASSERT(!list.isEmpty());
-    QModelIndex movedIndex = list.first();
-    QString sourceCollection = movedIndex.parent().data().toString();
-    int sourceRow = movedIndex.row();
+    const auto movedIndex = firstMatchedIndex(*model, movedCollection);
+    Q_ASSERT(movedIndex.isValid());
+    const auto sourceCollection = movedIndex.parent().data().toString();
+    const auto  sourceRow = movedIndex.row();
 
-    FakeCollectionMovedCommand *moveCommand = new FakeCollectionMovedCommand(movedCollection, sourceCollection, targetCollection, serverData);
+    const auto moveCommand = new FakeCollectionMovedCommand(movedCollection, sourceCollection, targetCollection, serverData);
 
     m_modelSpy->startSpying();
-    serverData->setCommands(QList<FakeAkonadiServerCommand *>() << moveCommand);
-
-    QList<ExpectedSignal> expectedSignals;
-
-    expectedSignals << getExpectedSignal(RowsAboutToBeMoved, sourceRow, sourceRow, sourceCollection, 0, targetCollection, QVariantList() << movedCollection);
-    expectedSignals << getExpectedSignal(RowsMoved, sourceRow, sourceRow, sourceCollection, 0, targetCollection , QVariantList() << movedCollection);
+    serverData->setCommands({moveCommand});
 
+    const QList<ExpectedSignal> expectedSignals {
+        {RowsAboutToBeMoved, sourceRow, sourceRow, sourceCollection, 0, targetCollection, {movedCollection}},
+        {RowsMoved, sourceRow, sourceRow, sourceCollection, 0, targetCollection , {movedCollection}}
+    };
     m_modelSpy->setExpectedSignals(expectedSignals);
     serverData->processNotifications();
 
@@ -310,25 +283,25 @@ void EntityTreeModelTest::testCollectionAdded()
     QFETCH(QString, addedCollection);
     QFETCH(QString, parentCollection);
 
-    QPair<FakeServerData *, Akonadi::EntityTreeModel *> testDrivers = populateModel(serverContent);
-    FakeServerData *serverData = testDrivers.first;
+    const auto testDrivers = populateModel(serverContent);
+    const auto serverData = testDrivers.first;
 
-    FakeCollectionAddedCommand *addCommand = new FakeCollectionAddedCommand(addedCollection, parentCollection, serverData);
+    const auto addCommand = new FakeCollectionAddedCommand(addedCollection, parentCollection, serverData);
 
     m_modelSpy->startSpying();
-    serverData->setCommands(QList<FakeAkonadiServerCommand *>() << addCommand);
+    serverData->setCommands({addCommand});
 
-    QList<ExpectedSignal> expectedSignals;
-
-    expectedSignals << getExpectedSignal(RowsAboutToBeInserted, 0, 0, parentCollection, QVariantList() << addedCollection);
-    expectedSignals << getExpectedSignal(RowsInserted, 0, 0, parentCollection, QVariantList() << addedCollection);
-    //The data changed signal comes from the item fetch job that is triggered because we have ImmediatePopulation enabled
-    expectedSignals << getExpectedSignal(DataChanged, 0, 0, parentCollection, QVariantList() << addedCollection);
+    const QList<ExpectedSignal> expectedSignals {
+        {RowsAboutToBeInserted, 0, 0, parentCollection, QVariantList{addedCollection}},
+        {RowsInserted, 0, 0, parentCollection, QVariantList{addedCollection}},
+        // The data changed signal comes from the item fetch job that is triggered because we have ImmediatePopulation enabled
+        {DataChanged, 0, 0, parentCollection, QVariantList{addedCollection}}
+    };
 
     m_modelSpy->setExpectedSignals(expectedSignals);
     serverData->processNotifications();
 
-    // Give the model a change to run the event loop to process the signals.
+    // Give the model a chance to run the event loop to process the signals.
     QTest::qWait(0);
 
     QVERIFY(m_modelSpy->isEmpty());
@@ -354,30 +327,28 @@ void EntityTreeModelTest::testCollectionRemoved()
     QFETCH(QString, serverContent);
     QFETCH(QString, removedCollection);
 
-    QPair<FakeServerData *, Akonadi::EntityTreeModel *> testDrivers = populateModel(serverContent);
-    FakeServerData *serverData = testDrivers.first;
-    Akonadi::EntityTreeModel *model = testDrivers.second;
+    const auto testDrivers = populateModel(serverContent);
+    const auto serverData = testDrivers.first;
+    const auto model = testDrivers.second;
 
-    QModelIndexList list = model->match(model->index(0, 0), Qt::DisplayRole, removedCollection, 1, Qt::MatchRecursive);
-    Q_ASSERT(!list.isEmpty());
-    QModelIndex removedIndex = list.first();
-    QString parentCollection = removedIndex.parent().data().toString();
-    int sourceRow = removedIndex.row();
+    const auto removedIndex = firstMatchedIndex(*model, removedCollection);
+    const auto parentCollection = removedIndex.parent().data().toString();
+    const auto sourceRow = removedIndex.row();
 
-    FakeCollectionRemovedCommand *removeCommand = new FakeCollectionRemovedCommand(removedCollection, parentCollection, serverData);
+    const auto removeCommand = new FakeCollectionRemovedCommand(removedCollection, parentCollection, serverData);
 
     m_modelSpy->startSpying();
-    serverData->setCommands(QList<FakeAkonadiServerCommand *>() << removeCommand);
+    serverData->setCommands({removeCommand});
 
-    QList<ExpectedSignal> expectedSignals;
-
-    expectedSignals << getExpectedSignal(RowsAboutToBeRemoved, sourceRow, sourceRow, parentCollection, QVariantList() << removedCollection);
-    expectedSignals << getExpectedSignal(RowsRemoved, sourceRow, sourceRow, parentCollection , QVariantList() << removedCollection);
+    const QList<ExpectedSignal> expectedSignals {
+        {RowsAboutToBeRemoved, sourceRow, sourceRow, parentCollection, QVariantList{removedCollection}},
+        {RowsRemoved, sourceRow, sourceRow, parentCollection , QVariantList{removedCollection}}
+    };
 
     m_modelSpy->setExpectedSignals(expectedSignals);
     serverData->processNotifications();
 
-    // Give the model a change to run the event loop to process the signals.
+    // Give the model a chance to run the event loop to process the signals.
     QTest::qWait(0);
 
     QVERIFY(m_modelSpy->isEmpty());
@@ -406,30 +377,28 @@ void EntityTreeModelTest::testCollectionChanged()
     QFETCH(QString, collectionName);
     QFETCH(QString, monitoredMimeType);
 
-    QPair<FakeServerData *, Akonadi::EntityTreeModel *> testDrivers = populateModel(serverContent, monitoredMimeType);
-    FakeServerData *serverData = testDrivers.first;
-    Akonadi::EntityTreeModel *model = testDrivers.second;
+    const auto testDrivers = populateModel(serverContent);
+    const auto serverData = testDrivers.first;
+    const auto model = testDrivers.second;
 
-    QModelIndexList list = model->match(model->index(0, 0), Qt::DisplayRole, collectionName, 1, Qt::MatchRecursive);
-    Q_ASSERT(!list.isEmpty());
-    QModelIndex changedIndex = list.first();
-    QString parentCollection = changedIndex.parent().data().toString();
+    const auto changedIndex = firstMatchedIndex(*model, collectionName);
+    const auto parentCollection = changedIndex.parent().data().toString();
     qDebug() << parentCollection;
-    int changedRow = changedIndex.row();
+    const auto changedRow = changedIndex.row();
 
-    FakeCollectionChangedCommand *changeCommand = new FakeCollectionChangedCommand(collectionName, parentCollection, serverData);
+    const auto changeCommand = new FakeCollectionChangedCommand(collectionName, parentCollection, serverData);
 
     m_modelSpy->startSpying();
-    serverData->setCommands(QList<FakeAkonadiServerCommand *>() << changeCommand);
+    serverData->setCommands({changeCommand});
 
-    QList<ExpectedSignal> expectedSignals;
-
-    expectedSignals << getExpectedSignal(DataChanged, changedRow, changedRow, parentCollection, QVariantList() << collectionName);
+    const QList<ExpectedSignal> expectedSignals {
+        {DataChanged, changedRow, changedRow, parentCollection, QVariantList{collectionName}}
+    };
 
     m_modelSpy->setExpectedSignals(expectedSignals);
     serverData->processNotifications();
 
-    // Give the model a change to run the event loop to process the signals.
+    // Give the model a chance to run the event loop to process the signals.
     QTest::qWait(0);
 
     QVERIFY(m_modelSpy->isEmpty());
@@ -455,40 +424,36 @@ void EntityTreeModelTest::testItemMove()
     QFETCH(QString, movedItem);
     QFETCH(QString, targetCollection);
 
-    QPair<FakeServerData *, Akonadi::EntityTreeModel *> testDrivers = populateModel(serverContent);
-    FakeServerData *serverData = testDrivers.first;
-    Akonadi::EntityTreeModel *model = testDrivers.second;
+    const auto testDrivers = populateModel(serverContent);
+    const auto serverData = testDrivers.first;
+    const auto model = testDrivers.second;
 
-    QModelIndexList list = model->match(model->index(0, 0), Qt::DisplayRole, movedItem, 1, Qt::MatchRecursive);
-    Q_ASSERT(!list.isEmpty());
-    QModelIndex movedIndex = list.first();
-    QString sourceCollection = movedIndex.parent().data().toString();
-    int sourceRow = movedIndex.row();
+    const auto movedIndex = firstMatchedIndex(*model, movedItem);
+    const auto sourceCollection = movedIndex.parent().data().toString();
+    const auto sourceRow = movedIndex.row();
 
-    QModelIndexList targetList = model->match(model->index(0, 0), Qt::DisplayRole, targetCollection, 1, Qt::MatchRecursive);
-    Q_ASSERT(!targetList.isEmpty());
-    QModelIndex targetIndex = targetList.first();
-    int targetRow = model->rowCount(targetIndex);
+    const auto targetIndex = firstMatchedIndex(*model, targetCollection);
+    const auto targetRow = model->rowCount(targetIndex);
 
-    FakeItemMovedCommand *moveCommand = new FakeItemMovedCommand(movedItem, sourceCollection, targetCollection, serverData);
+    const auto moveCommand = new FakeItemMovedCommand(movedItem, sourceCollection, targetCollection, serverData);
 
     m_modelSpy->startSpying();
-    serverData->setCommands(QList<FakeAkonadiServerCommand *>() << moveCommand);
+    serverData->setCommands({moveCommand});
 
-    QList<ExpectedSignal> expectedSignals;
-
-    //Currently moves are implemented as remove + insert in the ETM.
-    expectedSignals << getExpectedSignal(RowsAboutToBeRemoved, sourceRow, sourceRow, sourceCollection, QVariantList() << movedItem);
-    expectedSignals << getExpectedSignal(RowsRemoved, sourceRow, sourceRow, sourceCollection, QVariantList() << movedItem);
-    expectedSignals << getExpectedSignal(RowsAboutToBeInserted, targetRow, targetRow, targetCollection, QVariantList() << movedItem);
-    expectedSignals << getExpectedSignal(RowsInserted, targetRow, targetRow, targetCollection, QVariantList() << movedItem);
-//   expectedSignals << getExpectedSignal( RowsAboutToBeMoved, sourceRow, sourceRow, sourceCollection, targetRow, targetCollection, QVariantList() << movedItem );
-//   expectedSignals << getExpectedSignal( RowsMoved, sourceRow, sourceRow, sourceCollection, targetRow, targetCollection, QVariantList() << movedItem );
+    const QList<ExpectedSignal> expectedSignals {
+        //Currently moves are implemented as remove + insert in the ETM.
+        {RowsAboutToBeRemoved, sourceRow, sourceRow, sourceCollection, QVariantList{movedItem}},
+        {RowsRemoved, sourceRow, sourceRow, sourceCollection, QVariantList{movedItem}},
+        {RowsAboutToBeInserted, targetRow, targetRow, targetCollection, QVariantList{movedItem}},
+        {RowsInserted, targetRow, targetRow, targetCollection, QVariantList{movedItem}},
+        // {RowsAboutToBeMoved, sourceRow, sourceRow, sourceCollection, targetRow, targetCollection, QVariantList{movedItem}},
+        // {RowsMoved, sourceRow, sourceRow, sourceCollection, targetRow, targetCollection, QVariantList{movedItem}},
+    };
 
     m_modelSpy->setExpectedSignals(expectedSignals);
     serverData->processNotifications();
 
-    // Give the model a change to run the event loop to process the signals.
+    // Give the model a chance to run the event loop to process the signals.
     QTest::qWait(0);
 
     QVERIFY(m_modelSpy->isEmpty());
@@ -515,29 +480,27 @@ void EntityTreeModelTest::testItemAdded()
     QFETCH(QString, addedItem);
     QFETCH(QString, parentCollection);
 
-    QPair<FakeServerData *, Akonadi::EntityTreeModel *> testDrivers = populateModel(serverContent);
-    FakeServerData *serverData = testDrivers.first;
-    Akonadi::EntityTreeModel *model = testDrivers.second;
+    const auto testDrivers = populateModel(serverContent);
+    const auto serverData = testDrivers.first;
+    const auto model = testDrivers.second;
 
-    QModelIndexList list = model->match(model->index(0, 0), Qt::DisplayRole, parentCollection, 1, Qt::MatchRecursive);
-    Q_ASSERT(!list.isEmpty());
-    QModelIndex parentIndex = list.first();
-    int targetRow = model->rowCount(parentIndex);
+    const auto parentIndex = firstMatchedIndex(*model, parentCollection);
+    const auto targetRow = model->rowCount(parentIndex);
 
-    FakeItemAddedCommand *addedCommand = new FakeItemAddedCommand(addedItem, parentCollection, serverData);
+    const auto addedCommand = new FakeItemAddedCommand(addedItem, parentCollection, serverData);
 
     m_modelSpy->startSpying();
 
-    serverData->setCommands(QList<FakeAkonadiServerCommand *>() << addedCommand);
-    QList<ExpectedSignal> expectedSignals;
-
-    expectedSignals << getExpectedSignal(RowsAboutToBeInserted, targetRow, targetRow, parentCollection, QVariantList() << addedItem);
-    expectedSignals << getExpectedSignal(RowsInserted, targetRow, targetRow, parentCollection, QVariantList() << addedItem);
+    serverData->setCommands({addedCommand});
 
+    const QList<ExpectedSignal> expectedSignals {
+        {RowsAboutToBeInserted, targetRow, targetRow, parentCollection, QVariantList{addedItem}},
+        {RowsInserted, targetRow, targetRow, parentCollection, QVariantList{addedItem}}
+    };
     m_modelSpy->setExpectedSignals(expectedSignals);
     serverData->processNotifications();
 
-    // Give the model a change to run the event loop to process the signals.
+    // Give the model a chance to run the event loop to process the signals.
     QTest::qWait(0);
 
     QVERIFY(m_modelSpy->isEmpty());
@@ -570,30 +533,28 @@ void EntityTreeModelTest::testItemRemoved()
     QFETCH(QString, serverContent);
     QFETCH(QString, removedItem);
 
-    QPair<FakeServerData *, Akonadi::EntityTreeModel *> testDrivers = populateModel(serverContent);
-    FakeServerData *serverData = testDrivers.first;
-    Akonadi::EntityTreeModel *model = testDrivers.second;
+    const auto testDrivers = populateModel(serverContent);
+    const auto serverData = testDrivers.first;
+    const auto model = testDrivers.second;
 
-    const QModelIndexList list = model->match(model->index(0, 0), Qt::DisplayRole, removedItem, 1, Qt::MatchRecursive);
-    Q_ASSERT(!list.isEmpty());
-    QModelIndex removedIndex = list.first();
-    const QString sourceCollection = removedIndex.parent().data().toString();
-    int sourceRow = removedIndex.row();
+    const auto removedIndex = firstMatchedIndex(*model, removedItem);
+    const auto sourceCollection = removedIndex.parent().data().toString();
+    const auto sourceRow = removedIndex.row();
 
-    FakeItemRemovedCommand *removeCommand = new FakeItemRemovedCommand(removedItem, sourceCollection, serverData);
+    const auto removeCommand = new FakeItemRemovedCommand(removedItem, sourceCollection, serverData);
 
     m_modelSpy->startSpying();
-    serverData->setCommands(QList<FakeAkonadiServerCommand *>() << removeCommand);
+    serverData->setCommands({removeCommand});
 
-    QList<ExpectedSignal> expectedSignals;
-
-    expectedSignals << getExpectedSignal(RowsAboutToBeRemoved, sourceRow, sourceRow, sourceCollection, QVariantList() << removedItem);
-    expectedSignals << getExpectedSignal(RowsRemoved, sourceRow, sourceRow, sourceCollection, QVariantList() << removedItem);
+    const QList<ExpectedSignal> expectedSignals {
+        {RowsAboutToBeRemoved, sourceRow, sourceRow, sourceCollection, QVariantList{removedItem}},
+        {RowsRemoved, sourceRow, sourceRow, sourceCollection, QVariantList{removedItem}}
+    };
 
     m_modelSpy->setExpectedSignals(expectedSignals);
     serverData->processNotifications();
 
-    // Give the model a change to run the event loop to process the signals.
+    // Give the model a chance to run the event loop to process the signals.
     QTest::qWait(0);
 
     QVERIFY(m_modelSpy->isEmpty());
@@ -626,29 +587,27 @@ void EntityTreeModelTest::testItemChanged()
     QFETCH(QString, serverContent);
     QFETCH(QString, changedItem);
 
-    QPair<FakeServerData *, Akonadi::EntityTreeModel *> testDrivers = populateModel(serverContent);
-    FakeServerData *serverData = testDrivers.first;
-    Akonadi::EntityTreeModel *model = testDrivers.second;
+    const auto testDrivers = populateModel(serverContent);
+    const auto serverData = testDrivers.first;
+    const auto model = testDrivers.second;
 
-    QModelIndexList list = model->match(model->index(0, 0), Qt::DisplayRole, changedItem, 1, Qt::MatchRecursive);
-    Q_ASSERT(!list.isEmpty());
-    QModelIndex changedIndex = list.first();
-    QString parentCollection = changedIndex.parent().data().toString();
-    int sourceRow = changedIndex.row();
+    const auto changedIndex = firstMatchedIndex(*model, changedItem);
+    const auto parentCollection = changedIndex.parent().data().toString();
+    const auto sourceRow = changedIndex.row();
 
-    FakeItemChangedCommand *changeCommand = new FakeItemChangedCommand(changedItem, parentCollection, serverData);
+    const auto changeCommand = new FakeItemChangedCommand(changedItem, parentCollection, serverData);
 
     m_modelSpy->startSpying();
-    serverData->setCommands(QList<FakeAkonadiServerCommand *>() << changeCommand);
+    serverData->setCommands({changeCommand});
 
-    QList<ExpectedSignal> expectedSignals;
-
-    expectedSignals << getExpectedSignal(DataChanged, sourceRow, sourceRow, QVariantList() << changedItem);
+    const QList<ExpectedSignal> expectedSignals {
+        {DataChanged, sourceRow, sourceRow, QVariantList{changedItem}}
+    };
 
     m_modelSpy->setExpectedSignals(expectedSignals);
     serverData->processNotifications();
 
-    // Give the model a change to run the event loop to process the signals.
+    // Give the model a chance to run the event loop to process the signals.
     QTest::qWait(0);
 
     QVERIFY(m_modelSpy->isEmpty());
@@ -656,32 +615,32 @@ void EntityTreeModelTest::testItemChanged()
 
 void EntityTreeModelTest::testRemoveCollectionOnChanged()
 {
-    const QString serverContent = QStringLiteral(
-                                      "- C (inode/directory, text/directory)  'Col 1'     2"
-                                      "- - C (text/directory)                 'Col 2'     1"
-                                      "- - - I text/directory                 'Item 1'");
-    const QString collectionName = QStringLiteral("Col 2");
-    const QString monitoredMimeType = QStringLiteral("text/directory");
+    const auto serverContent = QStringLiteral(
+        "- C (inode/directory, text/directory)  'Col 1'     2"
+        "- - C (text/directory)                 'Col 2'     1"
+        "- - - I text/directory                 'Item 1'"
+    );
+    const auto collectionName = QStringLiteral("Col 2");
+    const auto monitoredMimeType = QStringLiteral("text/directory");
 
-    QPair<FakeServerData *, Akonadi::EntityTreeModel *> testDrivers = populateModel(serverContent, monitoredMimeType);
-    FakeServerData *serverData = testDrivers.first;
-    Akonadi::EntityTreeModel *model = testDrivers.second;
+    const auto testDrivers = populateModel(serverContent, monitoredMimeType);
+    const auto serverData = testDrivers.first;
+    const auto model = testDrivers.second;
 
-    QModelIndexList list = model->match(model->index(0, 0), Qt::DisplayRole, collectionName, 1, Qt::MatchRecursive);
-    Q_ASSERT(!list.isEmpty());
-    QModelIndex changedIndex = list.first();
-    Akonadi::Collection changedCol = changedIndex.data(Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
-    changedCol.setContentMimeTypes(QStringList() << QStringLiteral("foobar"));
-    QString parentCollection = changedIndex.parent().data().toString();
+    const auto changedIndex = firstMatchedIndex(*model, collectionName);
+    auto changedCol = changedIndex.data(Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
+    changedCol.setContentMimeTypes({QStringLiteral("foobar")});
+    const auto parentCollection = changedIndex.parent().data().toString();
 
-    FakeCollectionChangedCommand *changeCommand = new FakeCollectionChangedCommand(changedCol, serverData);
+    const auto changeCommand = new FakeCollectionChangedCommand(changedCol, serverData);
 
     m_modelSpy->startSpying();
-    serverData->setCommands(QList<FakeAkonadiServerCommand *>() << changeCommand);
+    serverData->setCommands({changeCommand});
 
-    QList<ExpectedSignal> expectedSignals;
-    expectedSignals << getExpectedSignal(RowsAboutToBeRemoved, changedIndex.row(), changedIndex.row(), parentCollection, QVariantList() << collectionName);
-    expectedSignals << getExpectedSignal(RowsRemoved, changedIndex.row(), changedIndex.row(), parentCollection, QVariantList() << collectionName);
+    const QList<ExpectedSignal> expectedSignals {
+        {RowsAboutToBeRemoved, changedIndex.row(), changedIndex.row(), parentCollection, QVariantList{collectionName}},
+        {RowsRemoved, changedIndex.row(), changedIndex.row(), parentCollection, QVariantList{collectionName}},
+    };
 
     m_modelSpy->setExpectedSignals(expectedSignals);
     serverData->processNotifications();
