@@ -13,7 +13,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+ * License along with this library.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "setup.h"
@@ -22,6 +22,7 @@
 #include <agentinstance.h>
 #include <agentinstancecreatejob.h>
 #include <resourcesynchronizationjob.h>
+#include <private/standarddirs_p.h>
 
 #include <KConfig>
 #include <kconfiggroup.h>
@@ -45,7 +46,7 @@ bool SetupTest::startAkonadiDaemon()
                 this, &SetupTest::slotAkonadiDaemonProcessFinished);
     }
 
-    mAkonadiDaemonProcess->setProgram(QStringLiteral("akonadi_control"),
+    mAkonadiDaemonProcess->setProgram(Akonadi::StandardDirs::findExecutable(QStringLiteral("akonadi_control")),
                                       { QStringLiteral("--instance"), instanceId() });
     mAkonadiDaemonProcess->start();
     const bool started = mAkonadiDaemonProcess->waitForStarted(5000);
@@ -87,7 +88,7 @@ void SetupTest::setupAgents()
     }
 
     if (isSetupDone()) {
-        emit setupDone();
+        Q_EMIT setupDone();
     }
 }
 
@@ -111,7 +112,7 @@ void SetupTest::agentCreationResult(KJob *job)
     }
 
     if (isSetupDone()) {
-        emit setupDone();
+        Q_EMIT setupDone();
     }
 }
 
@@ -125,7 +126,7 @@ void SetupTest::synchronizationResult(KJob *job)
     }
 
     if (isSetupDone()) {
-        emit setupDone();
+        Q_EMIT setupDone();
     }
 }
 
@@ -404,7 +405,7 @@ void SetupTest::slotAkonadiDaemonProcessFinished(int exitCode)
 {
     if (mTrackAkonadiProcess || exitCode != EXIT_SUCCESS) {
         qWarning() << "Akonadi server process was terminated externally!";
-        emit serverExited(exitCode);
+        Q_EMIT serverExited(exitCode);
     }
     mAkonadiDaemonProcess = nullptr;
 }
