@@ -40,9 +40,6 @@
 
 #include <QCoreApplication>
 #include <QDir>
-#ifndef QT_NO_DEBUG
-#include <QFileSystemWatcher>
-#endif
 #include <QScopedPointer>
 #include <QSettings>
 #include <QDBusConnection>
@@ -54,9 +51,6 @@ static const bool enableAgentServerDefault = false;
 AgentManager::AgentManager(bool verbose, QObject *parent)
     : QObject(parent)
     , mAgentServer(nullptr)
-#ifndef QT_NO_DEBUG
-    , mAgentWatcher(new QFileSystemWatcher(this))
-#endif
     , mVerbose(verbose)
 {
     new AgentManagerAdaptor(this);
@@ -91,10 +85,6 @@ AgentManager::AgentManager(bool verbose, QObject *parent)
         connect(mAgentServer, &Akonadi::ProcessControl::unableToStart, this, &AgentManager::agentServerFailure);
         mAgentServer->start(QStringLiteral("akonadi_agent_server"), serviceArgs, Akonadi::ProcessControl::RestartOnCrash);
     }
-
-#ifndef QT_NO_DEBUG
-    connect(mAgentWatcher, &QFileSystemWatcher::fileChanged, this, &AgentManager::agentExeChanged);
-#endif
 }
 
 void AgentManager::continueStartup()
@@ -112,18 +102,6 @@ void AgentManager::continueStartup()
         Q_EMIT agentTypeAdded(info.identifier);
     }
 
-
-#ifndef QT_NO_DEBUG
-    const QStringList pathList = pluginInfoPathList();
-    for (const QString &path : pathList) {
-        QFileSystemWatcher *watcher = new QFileSystemWatcher(this);
-        watcher->addPath(path);
-
-        connect(watcher, &QFileSystemWatcher::directoryChanged,
-                this, &AgentManager::updatePluginInfos);
-    }
-#endif
-
     load();
     for (const AgentType &info : qAsConst(mAgents)) {
         ensureAutoStart(info);
@@ -467,6 +445,24 @@ void AgentManager::agentInstanceSynchronizeCollection(const QString &identifier,
     mAgentInstances.value(identifier)->resourceInterface()->synchronizeCollection(collection, recursive);
 }
 
+void AgentManager::agentInstanceSynchronizeTags(const QString &identifier)
+{
+    if (!checkResourceInterface(identifier, QStringLiteral("agentInstanceSynchronizeTags"))) {
+        return;
+    }
+
+    mAgentInstances.value(identifier)->resourceInterface()->synchronizeTags();
+}
+
+void AgentManager::agentInstanceSynchronizeRelations(const QString &identifier)
+{
+    if (!checkResourceInterface(identifier, QStringLiteral("agentInstanceSynchronizeRelations"))) {
+        return;
+    }
+
+    mAgentInstances.value(identifier)->resourceInterface()->synchronizeRelations();
+}
+
 void AgentManager::restartAgentInstance(const QString &identifier)
 {
     if (!checkInstance(identifier)) {
@@ -497,11 +493,6 @@ void AgentManager::updatePluginInfos()
 
 void AgentManager::readPluginInfos()
 {
-#ifndef QT_NO_DEBUG
-    if (!mAgentWatcher->files().isEmpty()) {
-        mAgentWatcher->removePaths(mAgentWatcher->files());
-    }
-#endif
     mAgents.clear();
 
     const QStringList pathList = pluginInfoPathList();
@@ -544,11 +535,6 @@ void AgentManager::readPluginInfos(const QDir &directory)
                     qCWarning(AKONADICONTROL_LOG) << "Executable" << agentInfo.exec << "for agent" << agentInfo.identifier << "could not be found!";
                     continue;
                 }
-#ifndef QT_NO_DEBUG
-                if (!mAgentWatcher->files().contains(executable)) {
-                    mAgentWatcher->addPath(executable);
-                }
-#endif
             }
 
             qCDebug(AKONADICONTROL_LOG) << "PLUGINS inserting: " << agentInfo.identifier << agentInfo.instanceCounter << agentInfo.capabilities;
