@@ -79,11 +79,7 @@ Connection::~Connection()
 
 void Connection::reconnect()
 {
-#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
     const bool ok = QMetaObject::invokeMethod(this, &Connection::doReconnect, Qt::QueuedConnection);
-#else
-    const bool ok = QMetaObject::invokeMethod(this, "doReconnect", Qt::QueuedConnection);
-#endif
     Q_ASSERT(ok);
     Q_UNUSED(ok)
 }
@@ -144,7 +140,6 @@ void Connection::doReconnect()
             }
             options.insert(pair.first(), pair.last());
         }
-        qCDebug(AKONADICORE_LOG) << protocol << options;
 
         if (protocol == "unix") {
             serverAddress = options.value(QStringLiteral("path"));
@@ -158,7 +153,7 @@ void Connection::doReconnect()
         const QString connectionConfigFile = StandardDirs::connectionConfigFile();
         const QFileInfo fileInfo(connectionConfigFile);
         if (!fileInfo.exists()) {
-            qCDebug(AKONADICORE_LOG) << "Akonadi Client Session: connection config file '"
+            qCWarning(AKONADICORE_LOG) << "Akonadi Client Session: connection config file '"
                                         "akonadi/akonadiconnectionrc' can not be found!";
         }
 
@@ -203,13 +198,8 @@ void Connection::doReconnect()
 
 void Connection::forceReconnect()
 {
-#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
     const bool ok = QMetaObject::invokeMethod(this, &Connection::doForceReconnect,
                     Qt::QueuedConnection);
-#else
-    const bool ok = QMetaObject::invokeMethod(this, "doForceReconnect",
-                    Qt::QueuedConnection);
-#endif
 
     Q_ASSERT(ok);
     Q_UNUSED(ok)
@@ -228,13 +218,8 @@ void Connection::doForceReconnect()
 
 void Connection::closeConnection()
 {
-#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
     const bool ok = QMetaObject::invokeMethod(this, &Connection::doCloseConnection,
                     Qt::QueuedConnection);
-#else
-    const bool ok = QMetaObject::invokeMethod(this, "doCloseConnection", Qt::QueuedConnection);
-#endif
-
     Q_ASSERT(ok);
     Q_UNUSED(ok)
 }
