@@ -26,7 +26,6 @@
 
 class KConfig;
 class KJob;
-class KProcess;
 struct QMetaObject;
 
 namespace Akonadi
@@ -82,8 +81,8 @@ private Q_SLOTS:
 
 private:
     QStringList mPendingDefaults;
-    KConfig *mConfig;
-    KConfig *mCurrentDefault;
+    KConfig *mConfig = nullptr;
+    KConfig *mCurrentDefault = nullptr;
 };
 
 }
