@@ -34,7 +34,7 @@
 #include <QCoreApplication>
 #include <QMetaMethod>
 #include <QDBusConnection>
-#include <QDBusConnectionInterface>
+#include <QDBusError>
 #include <QSqlQuery>
 #include <QSqlError>
 #include <QThread>
@@ -361,6 +361,7 @@ bool DbUpdater::complexUpdate_25()
             }
             qCDebug(AKONADISERVER_LOG) << "\t Moved part type" << partName << "to PartTypeTable";
         }
+        query.finish();
     }
 
     qCDebug(AKONADISERVER_LOG) << "Migrating data from PartTable to PartTable_new";
