@@ -52,12 +52,15 @@ public:
     bool isAutoIncrement;
     bool isPrimaryKey;
     bool isUnique;
+    bool isEnum;
     QString refTable;
     QString refColumn;
     QString defaultValue;
     ReferentialAction onUpdate;
     ReferentialAction onDelete;
     bool noUpdate;
+
+    QMap<QString, int> enumValueMap;
 };
 
 /**
@@ -104,7 +107,7 @@ public:
 };
 
 /**
-  * @short A helper class that describes the relation between to tables for the DbInitializer
+  * @short A helper class that describes the relation between two tables for the DbInitializer
   */
 class RelationDescription
 {
