@@ -136,6 +136,9 @@ void StorageJanitor::check() // implementation of `akonadictl fsck`
     inform("Flushing collection statistics memory cache...");
     CollectionStatistics::self()->expireCache();
 
+    inform("Making sure virtual search resource and collections exist");
+    ensureSearchCollection();
+
     /* TODO some ideas for further checks:
      * the collection tree is non-cyclic
      * content type constraints of collections are not violated
@@ -356,7 +359,7 @@ void StorageJanitor:: findOrphanedPimItemFlags()
         ++count;
         imapIds.append(sqb.query().value(0).toInt());
     }
-
+    sqb.query().finish();
     if (count > 0) {
         ImapSet set;
         set.add(imapIds);
@@ -391,6 +394,7 @@ void StorageJanitor::findOverlappingParts()
         inform(QLatin1Literal("Found overlapping part data: ") + qb.query().value(0).toString());
         // TODO: uh oh, this is bad, how do we recover from that?
     }
+    qb.query().finish();
 
     if (count > 0) {
         inform(QLatin1Literal("Found ") + QString::number(count) + QLatin1Literal(" overlapping parts - bad."));
@@ -447,6 +451,7 @@ void StorageJanitor::verifyExternalParts()
             part.update();
         }
     }
+    qb.query().finish();
     inform(QLatin1Literal("Found ") + QString::number(usedFiles.size()) + QLatin1Literal(" external parts."));
 
     // see what's left and move it to lost+found
@@ -558,6 +563,7 @@ void StorageJanitor::findRIDDuplicates()
             while (items.query().next()) {
                 itemsIds.push_back(items.query().value(0));
             }
+            items.query().finish();
             if (itemsIds.isEmpty()) {
                 // the mimetype filter may have dropped some entries from the
                 // duplicates query
@@ -586,7 +592,9 @@ void StorageJanitor::findRIDDuplicates()
                 inform(QStringLiteral("Error while deleting duplicates ") + items.query().lastError().text());
             }
         }
+        duplicates.query().finish();
     }
+    qb.query().finish();
 }
 
 void StorageJanitor::vacuum()
@@ -664,6 +672,7 @@ void StorageJanitor::checkSizeTreshold()
 
             inform(QStringLiteral("Moved part %1 from database into external file %2").arg(part.id()).arg(QString::fromLatin1(name)));
         }
+        query.finish();
     }
 
     {
@@ -708,6 +717,7 @@ void StorageJanitor::checkSizeTreshold()
             f.remove();
             inform(QStringLiteral("Moved part %1 from external file into database").arg(part.id()));
         }
+        query.finish();
     }
 }
 
@@ -751,6 +761,7 @@ void StorageJanitor::migrateToLevelledCacheHierarchy()
             inform(QStringLiteral("Migrated part %1 to new levelled cache").arg(id));
         }
     }
+    query.finish();
 }
 
 void StorageJanitor::findOrphanSearchIndexEntries()
@@ -817,12 +828,43 @@ void StorageJanitor::findOrphanSearchIndexEntries()
         while (itemQuery.next()) {
             searchResults.remove(itemQuery.value(0).toLongLong());
         }
+        itemQuery.finish();
 
         if (!searchResults.isEmpty()) {
             inform(QStringLiteral("Collection %1 search index contains %2 orphan items. Scheduling reindexing").arg(colId).arg(searchResults.count()));
             iface.call(QDBus::NoBlock, QStringLiteral("reindexCollection"), colId);
         }
     }
+    query.finish();
+}
+
+void StorageJanitor::ensureSearchCollection()
+{
+    static const auto searchResourceName = QStringLiteral("akonadi_search_resource");
+
+    auto searchResource = Resource::retrieveByName(searchResourceName);
+    if (!searchResource.isValid()) {
+        searchResource.setName(searchResourceName);
+        searchResource.setIsVirtual(true);
+        if (!searchResource.insert()) {
+            inform(QStringLiteral("Failed to create Search resource."));
+            return;
+        }
+    }
+
+    auto searchCols = Collection::retrieveFiltered(Collection::resourceIdColumn(), searchResource.id());
+    if (searchCols.isEmpty()) {
+        Collection searchCol;
+        searchCol.setId(1);
+        searchCol.setName(QStringLiteral("Search"));
+        searchCol.setResource(searchResource);
+        searchCol.setIndexPref(Collection::False);
+        searchCol.setIsVirtual(true);
+        if (!searchCol.insert()) {
+            inform(QStringLiteral("Failed to create Search Collection"));
+            return;
+        }
+    }
 }
 
 
