@@ -22,13 +22,23 @@
 
 #include <QObject>
 #include <QMutex>
+#include <QJsonObject>
+#include <QJsonDocument>
 
 #include "tracerinterface.h"
+#include <private/protocol_p.h>
 
 class QSettings;
 
 namespace Akonadi
 {
+
+namespace Protocol
+{
+class Command;
+using CommandPtr = QSharedPointer<Command>;
+}
+
 namespace Server
 {
 
@@ -53,6 +63,23 @@ public:
      */
     ~Tracer() override;
 
+    template<typename T>
+    typename std::enable_if<std::is_base_of<Protocol::Command, T>::value>::type
+    connectionOutput(const QString &identifier, qint64 tag, const T &cmd) {
+        QByteArray msg;
+        if (mTracerBackend->connectionFormat() == TracerInterface::Json) {
+            QJsonObject json;
+            json[QStringLiteral("tag")] = tag;
+            cmd.toJson(json);
+            QJsonDocument doc(json);
+
+            msg = doc.toJson(QJsonDocument::Indented);
+        } else {
+            msg = QByteArray::number(tag) + ' ' + Protocol::debugString(cmd).toUtf8();
+        }
+        connectionOutput(identifier, msg);
+    }
+
 public Q_SLOTS:
     /**
      * This method is called whenever a new data (imap) connection to the akonadi server
@@ -84,6 +111,8 @@ public Q_SLOTS:
      */
     void connectionInput(const QString &identifier, const QByteArray &msg) override;
 
+    void connectionInput(const QString &identifier, qint64 tag, const Protocol::CommandPtr &cmd);
+
     /**
      * This method is called whenever the akonadi server sends some data out to a client.
      *
@@ -93,6 +122,8 @@ public Q_SLOTS:
      */
     void connectionOutput(const QString &identifier, const QByteArray &msg) override;
 
+    void connectionOutput(const QString &identifier, qint64 tag, const Protocol::CommandPtr &cmd);
+
     /**
      * This method is called whenever a dbus signal is emitted on the bus.
      *
