@@ -40,6 +40,7 @@
 
 #include <KSharedConfig>
 #include <KLocalizedString>
+#include <QDialogButtonBox>
 
 #include <memory>
 
@@ -56,14 +57,12 @@ AgentConfigurationWidget::Private::~Private()
 
 void AgentConfigurationWidget::Private::setupErrorWidget(QWidget *parent, const QString &text)
 {
-    auto layout = new QVBoxLayout;
+    QVBoxLayout *layout = new QVBoxLayout(parent);
     layout->addStretch(2);
     auto label = new QLabel(text, parent);
     label->setAlignment(Qt::AlignCenter);
     layout->addWidget(label);
     layout->addStretch(2);
-
-    parent->setLayout(layout);
 }
 
 bool AgentConfigurationWidget::Private::loadPlugin(const QString &pluginPath)
@@ -102,9 +101,9 @@ AgentConfigurationWidget::AgentConfigurationWidget(const AgentInstance &instance
             configName = Akonadi::ServerManager::addNamespace(configName);
             KSharedConfigPtr config = KSharedConfig::openConfig(configName);
             QVBoxLayout *layout = new QVBoxLayout(this);
-            layout->setMargin(0);
-            setLayout(layout);
+            layout->setContentsMargins(0, 0, 0, 0);
             d->plugin = d->factory->create(config, this, { instance.identifier() });
+            connect(d->plugin.data(), &AgentConfigurationBase::enableOkButton, this, &AgentConfigurationWidget::enableOkButton);
         } else {
             // Hide this dialog and fallback to calling the out-of-process configuration
             if (auto dlg = qobject_cast<AgentConfigurationDialog*>(parent)) {
@@ -153,6 +152,29 @@ void AgentConfigurationWidget::save()
     }
 }
 
+QSize AgentConfigurationWidget::restoreDialogSize() const
+{
+    if (d->plugin) {
+        return d->plugin->restoreDialogSize();
+    }
+    return {};
+}
+
+void AgentConfigurationWidget::saveDialogSize(const QSize &size)
+{
+    if (d->plugin) {
+        d->plugin->saveDialogSize(size);
+    }
+}
+
+QDialogButtonBox::StandardButtons AgentConfigurationWidget::standardButtons() const
+{
+    if (d->plugin) {
+        return d->plugin->standardButtons();
+    }
+    return QDialogButtonBox::Ok | QDialogButtonBox::Apply | QDialogButtonBox::Cancel;
+}
+
 void AgentConfigurationWidget::childEvent(QChildEvent *event)
 {
     if (event->added()) {
